@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.5905';
+our $VERSION = '0.5906';
 
 use warnings;
 use strict;
@@ -212,7 +212,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.5905
+version 0.5906
 
 =head1 SYNOPSIS
 
@@ -264,9 +264,9 @@ version 0.5905
 
 =head1 DESCRIPTION
 
-A C<Graph::Weighted> object is a subclass of the L<Graph> module with 
-attribute handling.  As such, all of the L<Graph> methods may be used
-as documented, but with the addition of custom weighting.
+A C<Graph::Weighted> object is a subclass of the L<Graph> module with attribute
+handling.  As such, all of the L<Graph> methods may be used as documented (e.g.
+L</"SHORTEST PATHS">), but with the addition of custom weighting.
 
 =head1 METHODS
 
@@ -388,13 +388,11 @@ Return the summed weight (or given cost attribute) of the path edges.
   @path = $apsp->path_vertices( 1, 3 ); # 1->4->2->3
   print 'Floyd-Warshall: ', join( '->', @path ), "\n";
 
-=head1 TO DO
-
-Find the total cost beneath a node.
-
 =head1 SEE ALSO
 
-L<Graph>
+L<Graph>, the parent of this module
+
+L<Graph::Easy::Weighted>, the sibling
 
 The F<eg/*> and F<t/*> file sources.
 
